"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.isMetadataRouteFile = isMetadataRouteFile;
exports.isMetadataRoute = isMetadataRoute;
var _discover = require("../../build/webpack/loaders/metadata/discover");
// Match routes that are metadata routes, e.g. /sitemap.xml, /favicon.<ext>, /<icon>.<ext>, etc.
// TODO-METADATA: support more metadata routes with more extensions
const defaultExtensions = [
    "js",
    "jsx",
    "ts",
    "tsx"
];
const getExtensionRegexString = (extensions)=>`(?:${extensions.join("|")})`;
function isMetadataRouteFile(appDirRelativePath, pageExtensions, withExtension) {
    const metadataRouteFilesRegex = [
        new RegExp(`^[\\\\/]robots${withExtension ? `\\.${getExtensionRegexString(pageExtensions.concat("txt"))}` : ""}`),
        new RegExp(`^[\\\\/]sitemap${withExtension ? `\\.${getExtensionRegexString(pageExtensions.concat("xml"))}` : ""}`),
        new RegExp(`^[\\\\/]manifest${withExtension ? `\\.${getExtensionRegexString(pageExtensions.concat("webmanifest", "json"))}` : ""}`),
        new RegExp(`^[\\\\/]favicon\\.ico$`),
        // TODO-METADATA: add dynamic routes for metadata images
        new RegExp(`[\\\\/]${_discover.STATIC_METADATA_IMAGES.icon.filename}${withExtension ? `\\.${getExtensionRegexString(pageExtensions.concat(_discover.STATIC_METADATA_IMAGES.icon.extensions))}` : ""}`),
        new RegExp(`[\\\\/]${_discover.STATIC_METADATA_IMAGES.apple.filename}${withExtension ? `\\.${getExtensionRegexString(pageExtensions.concat(_discover.STATIC_METADATA_IMAGES.apple.extensions))}` : ""}`),
        new RegExp(`[\\\\/]${_discover.STATIC_METADATA_IMAGES.openGraph.filename}${withExtension ? `\\.${getExtensionRegexString(pageExtensions.concat(_discover.STATIC_METADATA_IMAGES.openGraph.extensions))}` : ""}`),
        new RegExp(`[\\\\/]${_discover.STATIC_METADATA_IMAGES.twitter.filename}${withExtension ? `\\.${getExtensionRegexString(pageExtensions.concat(_discover.STATIC_METADATA_IMAGES.twitter.extensions))}` : ""}`), 
    ];
    return metadataRouteFilesRegex.some((r)=>r.test(appDirRelativePath));
}
function isMetadataRoute(route) {
    let page = route.replace(/^\/?app\//, "").replace(/\/route$/, "");
    if (page[0] !== "/") page = "/" + page;
    return !page.endsWith("/page") && isMetadataRouteFile(page, defaultExtensions, false);
}

//# sourceMappingURL=is-metadata-route.js.map